#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FMA_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FMA_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/fma.hpp>

#endif
